@@ -7,15 +7,19 @@ class ModelDiffMixin(object):
     to know what fields have been changed.
     """
 
+    __is_creation = False
+
     def __init__(self, *args, **kwargs):
         super(ModelDiffMixin, self).__init__(*args, **kwargs)
         self._saving_change_callbacks = False
         self.__initial = self._get_model_dict()
+        self.__is_creation = self.pk is None
 
     def save(self, *args, **kwargs):
         """
         Saves model and set initial state.
         """
+        self.__is_creation = self.pk is None
         if not self._saving_change_callbacks:
             self._saving_change_callbacks = True
             try:
@@ -56,6 +60,13 @@ class ModelDiffMixin(object):
         """
         return bool(self._get_diff())
 
+    @property
+    def is_creation(self):
+        """
+        True if the model is being created for the first time
+        """
+        return self.__is_creation
+
     @property
     def changed_fields(self):
         """
